JSON decoding wrapper for Claude Agent SDK.
Prefers OTP's built-in :json decoder when available and falls back to Jason
on older OTP releases.
JSON decoding wrapper for Claude Agent SDK.
Prefers OTP's built-in :json decoder when available and falls back to Jason
on older OTP releases.